Parameter options
-----------------

.. currentmodule:: yaw.options

The following string enumerations list commonly used configuration parameters
with a fixed set of options. They are interchangeable with string values and
are parsed and verified automatically:

.. autosummary::
    :toctree: autogen
    :template: enum.rst

    BinMethodAuto
    BinMethod
    Closed
    CovKind
    PlotStyle
    Unit
